@@ -54,3 +54,49 @@ sub _parse ($) {
 }
 
 1;
+
+__END__
+
+=encoding utf-8
+
+=head1 NAME
+
+MDOM::Assignment - DOM Assignment Node for Makefiles
+
+=head1 DESCRIPTION
+
+An assignment node.
+
+=head2 Accessors
+
+=over 4
+
+=item lhs
+
+left hand side of assignment
+
+=item rhs
+
+right hand side of assignment
+
+=item op
+
+assignment operator
+
+=back
+
+=head1 AUTHOR
+
+Yichun "agentzh" Zhang (章亦春) E<lt>agentzh@gmail.comE<gt>
+
+=head1 COPYRIGHT
+
+Copyright 2006-2014 by Yichun "agentzh" Zhang (章亦春).
+
+This library is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+=head1 SEE ALSO
+
+L<MDOM::Document>, L<MDOM::Document::Gmake>, L<PPI>, L<Makefile::Parser::GmakeDB>, L<makesimple>.
+
