@@ -37,7 +37,7 @@ my @keywords = qw(
 my $extract_interp_1 = gen_extract_tagged('\$[(]', '[)]', '');
 my $extract_interp_2 = gen_extract_tagged('\$[{]', '[}]', '');
 
-sub _extract_interp {
+sub extract_interp {
     my ($res) = $extract_interp_1->($_[0]);
     if (!$res) {
         ($res) = $extract_interp_2->($_[0]);
@@ -222,7 +222,7 @@ sub _tokenize_normal {
             # XXX This should be a separator...
             $next_token = MDOM::Token::Bare->new($&);
         }
-        elsif (my $res = _extract_interp($_)) {
+        elsif (my $res = extract_interp($_)) {
             $next_token = MDOM::Token::Interpolation->new($res);
         }
         elsif (/(?x) \G \$. /gc) {
@@ -284,7 +284,7 @@ sub _tokenize_command {
             $next_token = MDOM::Token::Whitespace->new("\n");
             #push @tokens, $next_token;
         }
-        elsif (my $res = _extract_interp($s)) {
+        elsif (my $res = extract_interp($s)) {
             $next_token = MDOM::Token::Interpolation->new($res);
         }
         elsif ($s =~ /(?x) \G \$. /gc) {
@@ -488,6 +488,12 @@ MDOM::Gmake - Represents a GNU makefile for Makefile::DOM
 
 Represents a GNU Makefile.
 
+=head1 METHODS
+
+=head2 C<extract_interp>
+
+Extract interpolated make variables like C<$(foo)> and C<${bar}>.
+
 =head1 AUTHOR
 
 Yichun "agentzh" Zhang (章亦春) E<lt>agentzh@gmail.comE<gt>
